from setuptools import find_packages, setup

setup(
    name='pytest-env-yaml',
    version='0.1.2',
    packages=find_packages(exclude=('tests',)),
    entry_points={
        'pytest11': [
            'env_yaml = pytest_env_yaml.plugin',
        ]
    },
    install_requires=[
        'pytest>=3.0.0',
        'PyYAML>=3.12'
    ]
)



import pytest
import yaml


def pytest_addoption(parser):
    parser.addoption('--env-yaml', action='store', default=None, required=True)


@pytest.fixture(scope='session')
def env_yaml(request):
    filename = request.config.getoption('--env-yaml')
    with open(filename) as stream:
        return yaml.load(stream)
